configure_with_options

Function configure_with_options 

pub fn configure_with_options<F>(
    builder: F,
    options: AdapterOptions,
) -> Result<(), AdapterError>
where F: Fn() -> Result<Arc<dyn Dispatcher>, AdapterError> + Send + Sync + 'static,
Configure the Lambda adapter with a dispatcher builder and explicit options.

The builder is invoked lazily on first request and the resulting dispatcher is cached for subsequent invocations in the same execution environment.