AWS Lambda runtime adapter for rivet applications.
This crate provides a worker-like developer experience for Lambda by exposing
a one-time configure step and per-invocation handle entrypoint.
Structs
- Adapter
Options - Runtime configuration for the Lambda adapter.
Enums
- Adapter
Error - Error type for adapter configuration and runtime initialization.
Functions
- configure
- Configure the Lambda adapter with a dispatcher builder and default options.
- configure_
with_ options - Configure the Lambda adapter with a dispatcher builder and explicit options.
- handle
- Handle a single Lambda invocation request.
- serve
- Start the Lambda runtime event loop using
handleas the request handler.