pub fn configure_with_options<F>(
builder: F,
options: AdapterOptions,
) -> Result<(), AdapterError>Expand description
Configure the Lambda adapter with a dispatcher builder and explicit options.
The builder is invoked lazily on first request and the resulting dispatcher is cached for subsequent invocations in the same execution environment.